gpdglmFit fits empirical or simulated data to the distribution,
print print method for a fitted GPD object of class ...,
plot plot method for a fitted GPD object,
summary summary method for a fitted GPD object,
gpdglmprofPlot profile log-likelihoods for return levels,
gpdglmprofxiPlot profile log-likelihoods for shape parameters. }gpdglmFit(x, threshold = min(x), npy = 365, y = NULL, sigl = NULL,
shl = NULL, siglink = identity, shlink = identity, show = FALSE,
method = "Nelder-Mead", maxit = 10000, ...)
## S3 method for class 'gpdglmFit':
print(x, \dots)
## S3 method for class 'gpdglmFit':
plot(x, which = "all", \dots)
## S3 method for class 'gpdglmFit':
summary(object, doplot = TRUE, which = "all", \dots)
gpdglmprofPlot(fit, m, xlow, xup, conf = 0.95, nint = 100, ...)
gpdglmprofxiPlot(fit, xlow, xup, conf = 0.95, nint = 100, ...)"gpdglm".m.optim for
details."gpdglmFit".TRUE (the default), print details of
the fit.ydat that contain covariates for generalized linear
modelling of the scale and shape parameters repectively
(or NULL (the default) if thxdat.c(TRUE, TRUE, TRUE, TRUE,
TRUE)."gpdglmFit".NULL (the default) for stationary
fitting). The number of rows should be the same as the length
of xdat.control argument of optim.show is
TRUE, then assuming that successful convergence is
indicated, the components nexc, nllh,
mle, rate and se are always printed.sigl and shl.optim. A zero indicates successful convergence.xdat).gpdSim.
Parameter Estimation:
gpdglmFit fits by the Maximum-likelihood approach the generalized
extreme value distribution, including generalized linear modelling
of each parameter.
Methods:
print.gpdglm, plot.gpdglm and summary.gpdglm
are print, plot, and summary methods for a fitted object of class
gpdglm.
Nonstationary Models:
For non-stationary fitting it is recommended that the covariates
within the generalized linear models are (at least approximately)
centered and scaled (i.e. the columns of ydat should be
approximately centered and scaled).mrlPlot,
ppFit.## Use Rain Data:
data(rain)
## Fit GPD Model:
xmpExtremes("Start: Parameter Estimation >")
fit = gpdglmFit(x = rain, threshold = 10)
print(fit)
xmpExtremes("Next: Summary Report > ")
## Summarize Results:
xmpExtremes("Next: Profile Likelihood >")
par(mfrow = c(2, 2), cex = 0.75)
summary(fit, which = "all")
# Profile Lielihood:
par(mfrow = c(2, 1), cex = 0.75)
gpdglmprofPlot(fit, m = 10, xlow = 55, xup = 75)
title(main = "Rain")
gpdglmprofxiPlot(fit, xlow = -0.02, 0.15)
title(main = "Rain")Run the code above in your browser using DataLab